/**
 * The Item class represents a multi-media item.
 * Information about the item is stored and can be retrieved.
 * This class serves as a superclass for more specific itms.
 * 
 * @author Michael Kolling and David J. Barnes
 * @version 2006.03.30
 * 
 * pld: note that accessors have been added for all fields
 */
public class Item
{
    private String title;
    private int playingTime;
    private boolean gotIt;
    private String comment;

    /**
     * Initialise the fields of the item.
     * @param theTitle The title of this item.
     * @param time The running time of this item.
     */
    public Item(String theTitle, int time)
    {
        title = theTitle;
        playingTime = time;
        gotIt = false;
        comment = "<no comment>";
    }

    /**
     * Get the title.
     */
    public String getTitle()
    {
        return title;
    }

    /**
     * Get the playing time.
     */
    public int getPlayingTime()
    {
        return playingTime;
    }


    /**
     * @return The comment for this item.
     */
    public String getComment()
    {
        return comment;
    }

    /**
     * Enter a comment for this item.
     * @param comment The comment to be entered.
     */
    public void setComment(String comment)
    {
        this.comment = comment;
    }
    
    /**
     * returns whether we have it
     */
    public boolean getOwn() {
        return gotIt;
    }

    /**
     * Set the flag indicating whether we own this item.
     * @param ownIt true if we own the item, false otherwise.
     */
    public void setOwn(boolean ownIt)
    {
        gotIt = ownIt;
    }
    
    /**
     * @return String containing class-specific info, for search()
     */
    public String keywords() {
        return "";
    }

    /**
     * Print details about this item to the text terminal.
     */
    public void print()
    {
        System.out.print("title: " + title + " (" + playingTime + " mins)");        
        if(gotIt) {
            System.out.println("*");
        } else {
            System.out.println();
        }
        System.out.println("    " + comment);
    }
}
